@@ -3,7 +3,6 @@ from typing import Annotated, Any, Optional, Sequence, Type, cast
 from fastapi import APIRouter, Body, Depends, HTTPException
 from motor.motor_asyncio import AsyncIOMotorDatabase
 
-from svc_infra.api.fastapi import public_router
 from svc_infra.api.fastapi.db.http import (
     LimitOffsetParams,
     OrderParams,
@@ -13,6 +12,7 @@ from svc_infra.api.fastapi.db.http import (
     dep_order,
     dep_search,
 )
+from svc_infra.api.fastapi.dual.public import public_router
 from svc_infra.db.nosql.mongo.client import acquire_db
 from svc_infra.db.nosql.service import NoSqlService
 
